@@ -1,3 +1,4 @@
+# pylint: disable=c-extension-no-member, consider-using-set-comprehension
 import re
 import sys
 from typing import Dict, Tuple
@@ -6,7 +7,8 @@ import ahocorasick
 
 
 def clean_text(text: str) -> str:
-    """Text cleaner
+    """
+    Text cleaner
     Below is a comprehensive list of changes:
         - remove the bullet lists marker
         - special characters
@@ -35,8 +37,7 @@ def clean_text(text: str) -> str:
 
 def read_word_lists(file_path: str, verbosity: int) -> Tuple[Dict, Dict]:
     """
-    reads lists in the format
-    firstPersonPronouns = I,we,me,us,my,our,myself,ourselves
+    Reads lists in the format: `"firstPersonPronouns = I,we,me,us,my,our,myself,ourselves"`
     """
     word_lists = {}
     mwe_list = {}
@@ -59,9 +60,9 @@ def read_word_lists(file_path: str, verbosity: int) -> Tuple[Dict, Dict]:
                     mwe_list[x[0]] = A
             else:
                 if verbosity > 0 and len(line) > 1:
-                    print("Error in line %i, %s" % (i, line), file=sys.stderr)
+                    print(f"Error in line {i}, {line}", file=sys.stderr)
     if verbosity > 1:
-        print("Read total %d classes" % len(word_lists), file=sys.stderr)
+        print(f"Read total {len(word_lists)} classes", file=sys.stderr)
         print(sorted(word_lists.keys()), file=sys.stderr)
     word_lists["specialVerbs"] = set.union(
         word_lists["publicVerbs"], word_lists["privateVerbs"], word_lists["suasiveVerbs"]
@@ -74,8 +75,7 @@ def read_word_lists(file_path: str, verbosity: int) -> Tuple[Dict, Dict]:
 
 def read_num_list(file_path: str) -> Dict:
     """
-    reads a numfile in the format
-    1625260 years year NOUN Number=Plur
+    Reads a numfile in the format: `"1625260 years year NOUN Number=Plur"`.
     This produces a "most frequent tag" substitute for tagging
     """
     tag_list = {}
